#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
key:                  http-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  820447ddae5e802a41e6888056f92dbe
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
depends:
    array-0.5.6.0 async-2.2.5-BExe3HBSFHr8hii1cT1bvS base-4.18.2.1
    base64-bytestring-1.2.1.0-6srVB7ZKmzD1HZV2AV5j9d
    blaze-builder-0.4.4.1-IalnSqFtizaBKkEQN83UwH bytestring-0.11.5.3
    case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1 ghc-prim-0.10.0
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    iproute-1.7.15-9uz1pfm3ZGxHhUe2hkNnB7
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-LsWsY6caX6uCNLTGwySDR3
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p stm-2.5.1.0
    streaming-commons-0.2.3.1-D1O7CCofCAb4YDJ83dqUtH text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

